# aautils.py
#
# Project: AutoArchive
# License: GNU GPLv3
#
# Copyright (C) 2003 - 2009 Robert Cernansky
# Copyright (C) 2003 - 2009 HOME software



"""Various functions and constants used across all modules.
"""



# INCLUDE FILES

import sys
import os
import os.path



# CONSTANTS

# debugging support
# >name of environment variable for switching the debugging
ENV_DEBUG = "AADEBUG"

DEBUG = os.environ.has_key(ENV_DEBUG) and os.environ[ENV_DEBUG]

# user configuration directory
USER_CONFIG_DIR = os.path.join("~",".config/aa")
if DEBUG: USER_CONFIG_DIR = os.path.join("../elab/.aa")

# subdirectory (in USER_CONFIG_DIR) for snapshots
SNAPSHOTS_DIR = "snapshots"



# CLASSES

class Enum(object):
    """Simple enum class.

    Example Usage:
    >>> codes = Enum("FOO", "BAR", "BAZ") # codes.BAZ will be 2 and so on ..."""

    def __init__(self, *names):
        self.count = len(names)

        for number, name in enumerate(names):
            setattr(self, name, number)



# FUNCTIONS

def createUserConfigDir():
    "Creates user configuration directory if it not exist."

    userConfigDirAbs = os.path.expanduser(USER_CONFIG_DIR)

    if not os.path.exists(userConfigDirAbs):
        os.makedirs(userConfigDirAbs)

    return userConfigDirAbs



def createSnapshotsDir():
    "Creates user snapshots subdirectory if it not exists."

    snapshotsDirAbs = os.path.join(createUserConfigDir(), SNAPSHOTS_DIR)

    if not os.path.exists(snapshotsDirAbs):
        os.mkdir(snapshotsDirAbs)

    return snapshotsDirAbs



def printError(msg):
    "Prints error message to stderr."

    if msg:
        sys.stderr.write(sys.argv[0] + ": " + msg + "\n")
